import unittest
import sys
import backtrader as bt
import numpy as np
import talib
import pandas as pd
from datetime import datetime
import time

sys.path.append("../")
from indicator.heikin_ashi import HA


class TestCase(unittest.TestCase):

    inputs = {
        'open': np.random.random(100),
        'high': np.random.random(100),
        'low': np.random.random(100),
        'close': np.random.random(100),
        'volume': np.random.random(100),
        'ts': np.random.random(100)
    }

    # dfTmp = pd.DataFrame(
    #     data=inputs, columns=['open', 'high', 'low', 'close', 'volume', 'ts'])
    # dfTmp = dfTmp.set_index('ts')

    ha = HA(o=inputs['open'],
            h=inputs['high'],
            l=inputs['low'],
            c=inputs['close'],
            v=inputs['volume'],
            ts=inputs['ts'])
    print('ha', ha)
    
    print('ha_close', ha['close'])
    print('len(ha_close)', len(ha['close']))
    print('type(ha)', type(ha))

    # inputs = {
    #     'open': [1, 2, 3, 4, 5],
    #     'high': [1, 2, 3, 4, 5],
    #     'low': [1, 2, 3, 4, 5],
    #     'close': [1, 2, 3, 4, 5],
    #     'volume': [1, 2, 3, 4, 5],
    #     'ts': [1, 2, 3, 4, 5]
    # }

    # ha = HA(o=inputs['open'],
    #         h=inputs['high'],
    #         l=inputs['low'],
    #         c=inputs['close'],
    #         v=inputs['volume'],
    #         ts=inputs['ts'])
    # print('ha', ha)
    # print('ha_close', ha['close'])
    # print('len(ha_close)', len(ha['close']))
    # print('type(ha)', type(ha))

    # ha = ha.shift(periods=1, freq="infer")
    ha = ha.shift(periods=-1)

    print('ha_close', ha['close'])
    print('len(ha_close)', len(ha['close']))
    # periods=3, freq="infer"


if __name__ == 'main':
    unittest.main()



import numpy as np
import math
from datetime import datetime

import sys

sys.path.append("../")


def RoundFunc(arrClose=[], decimal=3):
    '''
    @brief
    @return retCode 返回值，0 ，成功； 非0 ，失败；
    '''

    inputs = {
        'close': np.array(arrClose),
    }

    retCode = 4000
    retArr = np.round(inputs['close'], decimal)

    retCode = 0
    return retCode, retArr.tolist()


import math


def notNanCount(data=[]):
    count = 0
    for currItem in data:
        # print('currItem', currItem)
        if True != math.isnan(currItem):
            count += 1

    return count


def strNotNanCount(data=[]):
    count = notNanCount(data)
    return str(count) + "/" + str(len(data))



from __future__ import (absolute_import, division, print_function,
                        unicode_literals)


def checkPercent(paramPercent):
    if paramPercent <= 0 or paramPercent > 100:
        return False

    return True


from __future__ import (absolute_import, division, print_function,
                        unicode_literals)

import backtrader as bt
from datetime import datetime
import math


class Shift(bt.indicators.PeriodN):
    '''
    '''
    lines = ('localline', )

    def next(self):
        self.line[0] = self.data[-1 * self.p.period]

        # print(
        #     'Shift next()',
        #     'period',
        #     self.p.period,
        #     'self.data.get(size=20)',
        #     self.data.get(size=20),
        # )


def ShiftFunc(data=[], period=1):
    return data[:len(data) - period]



import unittest
import sys
import backtrader as bt
import numpy as np
import talib
import pandas as pd
from datetime import datetime

sys.path.append("../")
from indicator.crossover import CrossoverFunc


class TestCase(unittest.TestCase):

    arrLen = 8
    inputs = {
        'open': np.random.random(arrLen),
        # 'high': np.random.random(arrLen),
        # 'low': np.random.random(arrLen),
        'close': np.random.random(arrLen),
        # 'volume': np.random.random(arrLen),
        # 'ts': np.random.random(arrLen)
    }

    arrClose = inputs['close'].tolist()
    arrOpen = inputs['open'].tolist()

    print('arrClose', arrClose)
    print('arrOpen', arrOpen)
    resGen = CrossoverFunc(data0=arrClose, data1=arrOpen, period=3)
    print('resGen', resGen)


if __name__ == 'main':
    unittest.main()



import unittest
import sys
import order

sys.path.append("../")
from common.enums import Symbol


class TestCase(unittest.TestCase):

    resSize = order.quoteAmountToSize(symbol=Symbol['BTC/USDT:USDT'],
                                      qAmount=50,
                                      close=16000)

    print('resSize', resSize)


if __name__ == 'main':
    unittest.main()



import math
import unittest
import sys
import numpy as np
import talib

sys.path.append("../")
from indicator.bias import BiasFunc
from indicator.utils import RoundFunc, strNotNanCount


class TestCase(unittest.TestCase):

    size = 1000

    inputs = {
        'open': np.random.random(size),
        'high': np.random.random(size),
        'low': np.random.random(size),
        'close': np.random.random(size),
        'volume': np.random.random(size),
        'ts': np.random.random(size)
    }

    arrData = inputs['close'].tolist()
    # print('arrData', arrData, 'len(arrData)', len(arrData))

    retCode, retBias = BiasFunc(arrClose=arrData)

    if 0 == retCode:
        # print('retBias', retBias)
        retCode, roundBias = RoundFunc(retBias, decimal=5)
        # if 0 == retCode:
        #     print('roundBias', roundBias)

        print('BiasFunc exec ok',
              'retCode', retCode, 'strNotNanCount(retBias)',
              strNotNanCount(retBias), 'strNotNanCount(roundBias)',
              strNotNanCount(roundBias))


if __name__ == 'main':
    unittest.main()



import unittest
import sys
import backtrader as bt
import numpy as np
import talib
import pandas as pd
from datetime import datetime
import time

sys.path.append("../")
from indicator.shift import ShiftFunc


class TestCase(unittest.TestCase):

    inputs = {
        'open': np.random.random(100),
        'high': np.random.random(100),
        'low': np.random.random(100),
        'close': np.random.random(100),
        'volume': np.random.random(100),
        'ts': np.random.random(100)
    }

    # print('open', inputs['open'])
    # print('open', inputs['open'].tolist())
    arrData = inputs['open'].tolist()
    print('arrData', arrData, 'len(arrData)', len(arrData))

    # resGen = ShiftFunc(data=arrData, period=1)
    resGen = ShiftFunc(data=arrData, period=0)

    print('resGen', resGen, 'len(resGen)', len(resGen))


if __name__ == 'main':
    unittest.main()
